#pragma rtGlobals=3		// Use modern global access method and strict wave access.
#include ":AsylumResearch:Code3D:UserPanels:Nudger"

Window ForceFormula() : Panel
	
	PauseUpdate; Silent 1		// building window...
	NewPanel /K=1 /W=(907,464,1228,731)
	SetDrawLayer ProgBack
	SetDrawEnv linethick= 3,linefgc= (39168,13056,0),fillpat= 0
	DrawRect 3,3,318,264
	SetDrawLayer UserBack

	SetVariable s,pos={57,107},size={135,18},bodyWidth=80,title="Normal Sensitivity" 
	SetVariable s,font="Arial",fSize=12
	SetVariable s, format="%.2W1PV/m"
	SetVariable s,limits={-inf,inf,1},value= root:packages:DirectStepDataAcq:s
	
	SetVariable w,pos={57,87},size={135,18},bodyWidth=80,title="Cantilever Width" 
	SetVariable w,font="Arial",fSize=12
	SetVariable w, format="%.2W1Pum"
	SetVariable w,limits={-inf,inf,1e-06},value= root:packages:DirectStepDataAcq:w

	SetVariable l,pos={57,67},size={135,18},bodyWidth=80,title="Cantilever Length" 
	SetVariable l,font="Arial",fSize=12
	SetVariable l, format="%.2W1Pum"
	SetVariable l,limits={-inf,inf,1e-06},value= root:packages:DirectStepDataAcq:l
	
	SetVariable h,pos={57,47},size={135,18},bodyWidth=80,title="Cantilever Height" 
	SetVariable h,font="Arial",fSize=12
	SetVariable h, format="%.2W1Pum"
	SetVariable h,limits={-inf,inf,1e-06},value= root:packages:DirectStepDataAcq:h
	
	SetVariable f,pos={57,27},size={135,18},bodyWidth=80,title="Frequency" 
	SetVariable f,font="Arial",fSize=12
	SetVariable f, format="%.2W1PkHz"
	SetVariable f,limits={-inf,inf,1e03},value= root:packages:DirectStepDataAcq:f
	
	Button EnterVal,pos={107,127},size={85,18},proc=ForceFormulaEquations,title="Enter Values"
	Button EnterVal,font="Arial",fColor=(54272,53248,51200)

End

Function ForceFormulaEquations(ctrlname)

//Example Values: e = 1.69*10^11; w = 38.9*10^-6; l = 331.2*10^-6; h = 17.3*10^-6; p = 2330; f = 20.3*10^3, s = 0.033
	String ctrlname
	Variable w, l, h, f, e, g, p, A1, A2, A3, A4, A5, A6 //Variables A1-6 are just the formula solving for 'T' broken up into digestible pieces
	Variable T, NC, LFC1, LS
	e = 1.69*10^11
	p = 2330
	g = 5*10^10
	NVar w1 = root:packages:DirectStepDataAcq:w
		w = w1*10^-06
	NVar l1 = root:packages:DirectStepDataAcq:l
		l = l1*10^-06
	NVar h1 = root:packages:DirectStepDataAcq:h
		h = h1*10^-06
	NVar f1 = root:packages:DirectStepDataAcq:f
		f = f1*10^3
	NVar s = root:packages:DirectStepDataAcq:s
	NVar LFC2 = root:packages:DirectStepDataAcq:lfc

	Print "---Thickness---"
	A1 = 22300.602583139254*f^2*l^4*p*w
	A2 = 3.82507666875*10^13*e^2*f^2*h^3*l^3*p*pi*w^2
	A3 = e^(3/2)*sqrt(1.4631211521815597*10^27*e*f^4*h^6*l^6*p^2*pi^2*w^4 - 6.463058679534343*10^25*f^6*l^12*p^3*w^6)
	A4 =  (1/(e*w))*0.00005556959504194495
	A5 = 3.82507666875*10^13*e^2*f^2*h^3*l^3*p*pi*w^2
	A6 = e^(3/2)*sqrt(1.46312115218155*10^27*e*f^4*h^6*l^6*p^2*pi^2*w^4 - 6.4630586795343*10^25*f^6*l^12*p^3*w^6)
	T = A1/(A2 + A3)^(1/3) + A4*(A5 + A6)^(1/3)
	Print T
	
	Print "---Normal Force Constant (N/m)---"
	NC = (e*w*T^3/4)/l^3
	Print NC	
	
	Print "---Lateral Force Constant (N/m)---"
	LFC1 = g*w*T^3/(3*l*(h + T/2)^2)
	Print LFC1
	
	Print "---Lateral Sensitivity (V/m)---"
	LS = (2*g*l*s)/(e*(h + T/2))
	Print LS
	
	Print "---Lateral Force Constant (N/V)---"
	LFC2 = LFC1/LS
	Print LFC2
End

//T = (22300.602583139254*F^2*l^4*p*w)/(3.82507666875*10^13*e^2*F^2*h^3*l^3*p*pi*w^2 + e^(3/2)*sqrt(1.4631211521815597*10^27*e*F^4*h^6*l^6*p^2*pi^2*w^4 - 6.463058679534343*10^25*F^6*l^12*p^3*w^6))^(1/3) + (1/(e*w))*0.00005556959504194495*(3.82507666875*10^13*e^2*F^2*h^3*l^3*p*pi*w^2 + e^(3/2)*sqrt(1.46312115218155*10^27*e*F^4*h^6*l^6*p^2*pi^2*w^4 - 6.4630586795343*10^25*F^6*l^12*p^3*w^6))^(1/3)
//The thickness w/ example values is 1.12363*10^-6


Function RetrieveVariable(x)
	string x
	ControlInfo/W=ForceFormula2 x
	return(V_value)
End