#pragma rtGlobals=1        // Use modern global access method.


Function Pause()
	Variable time1, time2, totaltime
	
	time1 = ticks/60
	Do
		time2 = ticks/60
		totaltime = time2-time1
	While(totaltime < 2)
End		 


Function SingleStep2(s)
	Struct WMBackgroundStruct &s
	
	nvar running = root:packages:DirectStepDataAcq:running
	svar CtrlName = root:packages:DirectStepDataAcq:orienteering
	
	if(running ==0)
		return 0			// not running - wait for user
	endif	
			
	String Direction = CtrlName[0] //take the first letter of the control name which is X Y or Z
	Variable SignValue = StringMatch(CtrlName[1,Strlen(CtrlName)-1],"Up*")*2-1 //if up then SignValue is 1; if down then SignValue is -1
	Variable StepSize = GV("NudgerStepSize") //get the step size from the wave containing that information
	
	CheckNudgerLoops()
	
	Variable IsClosedLoop = GV("Nudger"+Direction+"Closed")  //GetValue nudgerXClosed, returns 0 for NudgerZClosed and returns 1 for X or Y direction
	if (StringMatch(Direction,"Z"))
		SignValue *= -1
	elseif (IsClosedLoop)
		SignValue *= GV(Direction+"ScanDirection")
	endif
	
	Variable CurrentPos
	Variable Sens
	String LoopStr = ""
	if (IsClosedLoop)
		Sens = GV(Direction+"LVDTSens")  // sensitivity of LVDTSens, used to convert um to V
		CurrentPos = Td_ReadValue("$output"+Direction+"Loop.Setpoint")  // currently setpoint of LDVT  in PIDSLoop wave under outputXLoop column
	else
		Sens = GV(Direction+"PiezoSens")  // Open-loop sensitivity factor for the X-axis piezo (um/V)  nonlinear so not accurate outside of small movements
		CurrentPos = td_readValue("output."+Direction)  // piezo drive on X axis
	endif
	StepSize /= Sens  // converts stepsize into volts
	StepSize *= SignValue  // applies sign indicating correct direction ie. right or left
	
	
	String ErrorStr = ""
	
//	PV("NudgerInAction",0)
//	GhostNudger()
	String RampChannel = ""
	if (IsClosedLoop)  // again this checks if we are using LVDT or piezo to control motion
		RampChannel = "$output"+Direction+"Loop.Setpoint"
	else
		RampChannel = "output."+Direction
	endif
	ErrorStr += num2str(td_SetRamp(.1, RampChannel,0,CurrentPos+StepSize,"",0,0,"",0,0,""))+","  //this moves the tip.  I deleted NudgerCallbackFunction from the end of td_SetRamp
	ARReportError(ErrorStr)
	
	if (Isitchecked()==1)
		DataStorage()
	endif
	
		ControlUpdate /A /W=ControlledStep
	
	return 0				 // continue this background task
	
End // End of function XStepLeft


Function StartRepeatedSteps(direction)
	string direction
	svar whichway = root:packages:DirectStepDataAcq:orienteering 
	nvar secondsBetweenRuns = root:packages:DirectStepDataAcq:speed
	Variable periodInTicks = 60 * secondsBetweenRuns				//run every 3 seconds
	
	whichway = direction
	CtrlNamedBackground RepeatedSteps,  period=periodInTicks, proc=SingleStep2
	CtrlNamedBackground RepeatedSteps, start
End	

Function StartStopProc(ctrlName) : ButtonControl
	String ctrlName
	nvar running =  root:packages:DirectStepDataAcq:running
	
	if( CmpStr(ctrlName, "StartButton") == 0 )
		running =1 
		Button $ctrlName, rename=StopButton,title="Stop"
	endif
	if( CmpStr(ctrlName, "StopButton") == 0)
		running =0
		Button  $ctrlName, rename=StartButton,title="Start"
		CtrlNamedBackground RepeatedSteps, stop
	endif
End

